"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDefaultMetaTags = getDefaultMetaTags;
exports.getGeneralHead = getGeneralHead;
exports.default = getMetaTags;

var _react = _interopRequireDefault(require("react"));

var _ramda = require("ramda");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function getDefaultMetaTags(_ref) {
  var favicons = _ref.favicons;
  return [{
    tag: 'meta',
    name: 'robots',
    content: 'index,follow'
  }, {
    tag: 'meta',
    name: 'googlebot',
    content: 'index,follow'
  }].concat((favicons || []).map(function (_ref2) {
    var sizes = _ref2.sizes,
        href = _ref2.href;
    return {
      tag: 'link',
      rel: 'icon',
      type: 'image/png',
      sizes: sizes,
      href: href
    };
  }));
}

function getGeneralHead(_ref3) {
  var url = _ref3.url,
      title = _ref3.title,
      description = _ref3.description,
      subject = _ref3.subject;
  return [title && {
    tag: 'title',
    children: title
  }, url && {
    tag: 'link',
    rel: 'canonical',
    href: url
  }, description && {
    tag: 'meta',
    name: 'description',
    content: description
  }, {
    tag: 'meta',
    name: 'subject',
    content: subject
  }];
}

function getFacebookHead(_ref4) {
  var appId = _ref4.appId,
      url = _ref4.url,
      title = _ref4.title,
      description = _ref4.description,
      imageUrl = _ref4.imageUrl,
      siteName = _ref4.siteName,
      locale = _ref4.locale,
      author = _ref4.author;
  return [appId && {
    tag: 'meta',
    property: 'fb:app_id',
    content: appId
  }, url && {
    tag: 'meta',
    property: 'og:url',
    content: url
  }, {
    tag: 'meta',
    property: 'og:type',
    content: 'website'
  }, title && {
    tag: 'meta',
    property: 'og:title',
    content: title
  }, imageUrl && {
    tag: 'meta',
    property: 'og:image',
    content: imageUrl
  }, description && {
    tag: 'meta',
    property: 'og:description',
    content: description
  }, siteName && {
    tag: 'meta',
    property: 'og:site_name',
    content: siteName
  }, locale && {
    tag: 'meta',
    property: 'og:locale',
    content: locale
  }, author && {
    tag: 'meta',
    property: 'article:author',
    content: author
  }];
}

function geTwitterHead(_ref5) {
  var url = _ref5.url,
      title = _ref5.title,
      description = _ref5.description,
      imageUrl = _ref5.imageUrl,
      twSiteAccount = _ref5.twSiteAccount,
      twCreator = _ref5.twCreator;
  return [{
    tag: 'meta',
    name: 'twitter:card',
    content: 'summary'
  }, twSiteAccount && {
    tag: 'meta',
    name: 'twitter:site',
    content: twSiteAccount
  }, twCreator && {
    tag: 'meta',
    name: 'twitter:creator',
    content: twCreator
  }, url && {
    tag: 'meta',
    name: 'twitter:url',
    content: url
  }, title && {
    tag: 'meta',
    name: 'twitter:title',
    content: title
  }, description && {
    tag: 'meta',
    name: 'twitter:description',
    content: description
  }, imageUrl && {
    tag: 'meta',
    name: 'twitter:image',
    content: imageUrl
  }];
}

function getGooglePlusHead(_ref6) {
  var title = _ref6.title,
      description = _ref6.description,
      imageUrl = _ref6.imageUrl,
      googlePlusPublisher = _ref6.googlePlusPublisher;
  return [googlePlusPublisher && {
    tag: 'link',
    href: googlePlusPublisher,
    rel: 'publisher'
  }, title && {
    tag: 'meta',
    itemProp: 'name',
    content: title
  }, description && {
    tag: 'meta',
    itemProp: 'description',
    content: description
  }, imageUrl && {
    tag: 'meta',
    itemProp: 'image',
    content: imageUrl
  }];
}

var generateKey = function generateKey(_ref7) {
  var tag = _ref7.tag,
      rel = _ref7.rel,
      property = _ref7.property,
      name = _ref7.name,
      itemProp = _ref7.itemProp;
  return "".concat(tag, ":").concat(rel, ":").concat(property, ":").concat(name, ":").concat(itemProp);
};

var transform = (0, _ramda.pipe)((0, _ramda.filter)(function (x) {
  return x;
}), _ramda.reverse, (0, _ramda.uniqBy)(generateKey), (0, _ramda.map)(function (item) {
  var _item$tag = item.tag,
      Tag = _item$tag === void 0 ? 'meta' : _item$tag,
      rest = _objectWithoutProperties(item, ["tag"]);

  return _react.default.createElement(Tag, _extends({
    key: generateKey(item)
  }, rest));
}));

function getMetaTags(_ref8) {
  var url = _ref8.url,
      title = _ref8.title,
      description = _ref8.description,
      subject = _ref8.subject,
      favicons = _ref8.favicons,
      imageUrl = _ref8.imageUrl,
      siteName = _ref8.siteName,
      locale = _ref8.locale,
      author = _ref8.author,
      fbAppId = _ref8.fbAppId,
      twSiteAccount = _ref8.twSiteAccount,
      twCreator = _ref8.twCreator,
      googlePlusPublisher = _ref8.googlePlusPublisher,
      _ref8$meta = _ref8.meta,
      meta = _ref8$meta === void 0 ? [] : _ref8$meta;

  var tagList = _toConsumableArray(getGeneralHead({
    url: url,
    title: title,
    description: description,
    subject: subject
  })).concat(_toConsumableArray(getDefaultMetaTags({
    favicons: favicons
  })), _toConsumableArray(getFacebookHead({
    fbAppId: fbAppId,
    author: author,
    url: url,
    title: title,
    description: description,
    imageUrl: imageUrl,
    siteName: siteName,
    locale: locale
  })), _toConsumableArray(geTwitterHead({
    url: url,
    title: title,
    description: description,
    imageUrl: imageUrl,
    twSiteAccount: twSiteAccount,
    twCreator: twCreator
  })), _toConsumableArray(getGooglePlusHead({
    title: title,
    description: description,
    imageUrl: imageUrl,
    googlePlusPublisher: googlePlusPublisher
  })), _toConsumableArray(meta));

  return transform(tagList);
}