// @flow

import React from 'react'
import Icon from 'components/Icon'
import { themr } from 'react-css-themr'

const SocialLinks = ({
  items,
  useColor,
  theme,
}: {
  items: { title: string, icon: string, url: string, color?: string }[],
  useColor?: boolean,
  theme: *,
}) => {
  if (!items) return null
  return (
    <div className={theme.root}>
      {items.map(({ icon, title, url, color }, idx) => (
        <div className={theme.itemWrapper} key={idx}>
          <a
            title={title}
            href={url}
            className={theme.link}
            style={useColor ? { color } : {}}
            target="_blank"
            rel="noopener noreferrer"
          >
            <Icon icon={icon} />
          </a>
        </div>
      ))}
    </div>
  )
}

SocialLinks.defaultProps = {
  useColor: true,
}

export default themr(
  'SocialLinks',
  { root: 'flex', itemWrapper: 'pa1', link: 'f3 gray' },
  { composeTheme: 'softly' },
)(SocialLinks)
